@@ -276,8 +276,8 @@ def get_devices(api_key: str = Depends(verify_api_key)):
     description="Get logs for the kalavai API service, including internal logs, debugging messages and status of the service.",
     tags=["info"],
     response_description="Logs")
-def get_service_logs(api_key: str = Depends(verify_api_key)):
-    return fetch_pod_logs(label_key=KALAVAI_SERVICE_LABEL, label_value=KALAVAI_SERVICE_LABEL_VALUE, force_namespace="kalavai")
+def get_service_logs(tail: int=100, api_key: str = Depends(verify_api_key)):
+    return fetch_pod_logs(label_key=KALAVAI_SERVICE_LABEL, label_value=KALAVAI_SERVICE_LABEL_VALUE, force_namespace="kalavai", tail=tail)
 
 @app.post("/send_pool_invites",
     operation_id="send_pool_invites",
@@ -327,15 +327,15 @@ def gpus(available: bool = False, api_key: str = Depends(verify_api_key)):
     """
     return fetch_gpus(available=available)
 
-@app.post("/fetch_job_details",
+@app.get("/fetch_job_details",
     operation_id="fetch_job_details",
     summary="Get detailed information about specific job and model deployments",
-    description="Given a list of jobs (as {'jobs': [{'name': job_name}]}'), retrieves comprehensive information about specified jobs or models including their status, resource usage, runtime, and configuration. Useful for monitoring and debugging job execution.",
+    description="Retrieves comprehensive information about jobs or models including their status, resource usage, runtime, and configuration. Useful for monitoring and debugging job execution.",
     tags=["info"],
     response_description="Job details")
-def job_details(request: JobDetailsRequest, api_key: str = Depends(verify_api_key)):
+def job_details(force_namespace: str = Query(None), api_key: str = Depends(verify_api_key)):
     """Get job details"""
-    return fetch_job_details(jobs=request.jobs)
+    return fetch_job_details(force_namespace=force_namespace)
 
 @app.get("/fetch_job_logs",
     operation_id="fetch_job_logs",
