@@ -227,13 +227,13 @@ def fetch_resources(node_names: list[str]=None):
 
 def fetch_job_defaults(name):
     data = {
-        "template": name
+        "template_name": name
     }
     try:
         metadata = request_to_server(
             method="get",
             endpoint="/v1/job_defaults",
-            data=data,
+            params=data,
             server_creds=USER_LOCAL_SERVER_FILE,
             user_cookie=USER_COOKIE
         )
@@ -259,85 +259,77 @@ def fetch_job_templates(type: str=None):
         return {"error": str(e)}
 
 def fetch_job_names():
-    data = {
-        "group": "batch.volcano.sh",
-        "api_version": "v1alpha1",
-        "plural": "jobs"
-    }
+    data_groups = [
+        {
+            "group": "batch.volcano.sh",
+            "api_version": "v1alpha1",
+            "plural": "jobs"
+        },
+        {
+            "group": "ray.io",
+            "api_version": "v1",
+            "plural": "rayclusters"
+        }
+    ]
     try:
-        jobs = request_to_server(
-            method="post",
-            endpoint="/v1/get_objects_of_type",
-            data=data,
-            server_creds=USER_LOCAL_SERVER_FILE,
-            user_cookie=USER_COOKIE
-        )
         all_jobs = []
-        for ns, ds in jobs.items():
-            all_jobs.extend([Job(owner=ns, name=d["metadata"]["labels"][TEMPLATE_LABEL]) for d in ds["items"]])
+        for data in data_groups:
+            jobs = request_to_server(
+                method="post",
+                endpoint="/v1/get_objects_of_type",
+                data=data,
+                server_creds=USER_LOCAL_SERVER_FILE,
+                user_cookie=USER_COOKIE
+            )
+            for ns, ds in jobs.items():
+                all_jobs.extend([Job(owner=ns, name=d["metadata"]["labels"][TEMPLATE_LABEL]) for d in ds["items"]])
+            
     except Exception as e:
         return {"error": str(e)}
     
     return all_jobs  
 
-def fetch_job_details(jobs: list[Job]):
-    """Get job details. A job is a dict:
-    {
-        "namespace": ns,
-        "name": name
-    }
-    """
+def fetch_job_details(force_namespace=None):
+    """Get jobs overview details (status and services)"""
     job_details = []
-    for job in jobs:
-        namespace = job.owner
-        deployment = job.name
-        try:
-            # get pod statuses
-            data = {
-                "label": TEMPLATE_LABEL,
-                "value": deployment
-            }
-            result = request_to_server(
-                method="post",
-                endpoint="/v1/get_pods_status_for_label",
-                data=data,
-                server_creds=USER_LOCAL_SERVER_FILE,
-                user_cookie=USER_COOKIE
-            )
+    # fetch all details at once
+    data = {"labels": [TEMPLATE_LABEL]}
+    if force_namespace is not None:
+        data["force_namespace"] = force_namespace
+    result = request_to_server(
+        method="post",
+        endpoint="/v1/get_jobs_overview",
+        data=data,
+        server_creds=USER_LOCAL_SERVER_FILE,
+        user_cookie=USER_COOKIE)
+
+    for namespace, deployments in result.items():
+        """deployments --> "matched_label_value": {"pods": [], "services": []} }"""
+        for job_name, job in deployments.items():
             workers_status = defaultdict(int)
             restart_counts = 0
             host_nodes = set()
-            for ns, ss in result.items():
-                if ns != namespace: # same job name, different namespace
-                    continue
-                for _, values in ss.items():
-                    if "conditions" in values and values["conditions"] is not None:
-                        restart_counts = sum([c["restart_count"] for c in values["conditions"]])
-                    workers_status[values["status"]] += 1
-                    # get nodes involved in deployment (needs kubewatcher)
-                    if "node_name" in values and values["node_name"] is not None:
-                        host_nodes.add(values["node_name"])
-
-            workers = "\n".join([f"{k}: {v}" for k, v in workers_status.items()])
-            if restart_counts > 0:
-                workers += f"\n({restart_counts} restart)"
-            # get URL details
-            data = {
-                "label": TEMPLATE_LABEL,
-                "value": deployment,
-                "types": ["NodePort"]
-            }
-            result = request_to_server(
-                method="post",
-                endpoint="/v1/get_ports_for_services",
-                data=data,
-                server_creds=USER_LOCAL_SERVER_FILE,
-                user_cookie=USER_COOKIE
-            )
-            #node_ports = [f"{p['node_port']} (mapped to {p['port']})" for s in result.values() for p in s["ports"]]
-            node_ports = [f"{p['node_port']}" for s in result.values() for p in s["ports"]]
-
-            urls = [f"http://{load_server_info(data_key=SERVER_IP_KEY, file=USER_LOCAL_SERVER_FILE)}:{node_port}" for node_port in node_ports]
+            # parse pods
+            for name, values in job["pods"].items():
+                if "conditions" in values and values["conditions"] is not None:
+                    restart_counts = sum([c["restart_count"] for c in values["conditions"]])
+                workers_status[values["status"]] += 1
+                # get nodes involved in deployment (needs kubewatcher)
+                if "node_name" in values and values["node_name"] is not None:
+                    host_nodes.add(values["node_name"])
+                workers = "\n".join([f"{k}: {v}" for k, v in workers_status.items()])
+                if restart_counts > 0:
+                    workers += f"\n({restart_counts} restart)"
+            # parse services
+            node_ports = []
+            if "services" in job and job["services"] is not None:
+                for name, values in job["services"].items():
+                    node_ports.extend(
+                        [f"{port['node_port']}" for port in values["ports"]]
+                    )
+                urls = [f"http://{load_server_info(data_key=SERVER_IP_KEY, file=USER_LOCAL_SERVER_FILE)}:{node_port}" for node_port in node_ports]
+            else:
+                urls = []
             if "Ready" in workers_status and len(workers_status) == 1:
                 status = "running"
             elif any([st in workers_status for st in ["Failed"]]):
@@ -350,16 +342,12 @@ def fetch_job_details(jobs: list[Job]):
                 status = "working"
             job_details.append(
                 Job(owner=namespace,
-                    name=deployment,
+                    name=job_name,
                     workers=workers,
                     endpoint="\n".join(urls),
                     status=str(status),
                     host_nodes=" ".join(host_nodes))
             )
-
-        except Exception as e:
-            return {"error": str(e)}
-    
     return job_details
 
 def deploy_job(template_name, values_dict, force_namespace=None, target_labels=None):
